@@ -9,8 +9,12 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 # ------------------------------------------------------------------
-import pytest
+
+import os
 from pathlib import Path
+
+import pytest
+
 from PyInstaller.compat import is_darwin, is_linux, is_py39, is_win
 from PyInstaller.utils.hooks import is_module_satisfies, can_import_module
 from PyInstaller.utils.tests import importorskip, requires, xfail
@@ -55,6 +59,20 @@ def test_tensorflow(pyi_builder):
     )
 
 
+# Test if tensorflow.keras imports properly result in tensorflow being collected.
+# See https://github.com/pyinstaller/pyinstaller/discussions/6890
+@importorskip('tensorflow')
+@tensorflow_onedir_only
+def test_tensorflow_keras_import(pyi_builder):
+    pyi_builder.test_source(
+        """
+        from tensorflow.keras.models import Sequential
+        from tensorflow.keras.layers import Dense, LSTM, Dropout
+        from tensorflow.keras.optimizers import Adam
+        """
+    )
+
+
 @importorskip('tensorflow')
 @tensorflow_onedir_only
 def test_tensorflow_layer(pyi_builder):
@@ -1018,6 +1036,48 @@ def test_cv2(pyi_builder):
         """)
 
 
+# Requires OpenCV with enabled HighGUI
+@importorskip("cv2")
+def test_cv2_highgui(pyi_builder):
+    from PyInstaller import isolated
+
+    @isolated.decorate
+    def _get_cv2_highgui_backend():
+        import re
+        import cv2
+
+        # Find `GUI: <type>` line in OpenCV build information dump. This is available only in recent OpenCV versions;
+        # in earlier versions, we would need to parse all subsequent backend entries, which is out of our scope here.
+        pattern = re.compile(r'$\s*GUI\s*:\s*(?P<gui>\S+)\s*^', re.MULTILINE)
+        info = cv2.getBuildInformation()
+        m = pattern.search(info)
+        if not m:
+            return None
+
+        return m.group('gui')
+
+    has_gui = True
+    backend = _get_cv2_highgui_backend()
+    if backend is None:
+        # We could not determine the backend from OpenCV information; fall back to the dist name
+        if is_module_satisfies('opencv-python-headless'):
+            has_gui = False
+    elif backend == "NONE":
+        has_gui = False
+
+    if not has_gui:
+        pytest.skip("OpenCV has no GUI support.")
+
+    pyi_builder.test_source("""
+        import cv2
+        import numpy as np
+
+        img = np.zeros((64, 64), dtype='uint8')
+        cv2.imshow("Test", img)
+        cv2.waitKey(1000)  # Wait a second
+        """)
+
+
 @importorskip("twisted")
 def test_twisted_default_reactor(pyi_builder):
     pyi_builder.test_source("""
@@ -1187,3 +1247,75 @@ def test_weasyprint(pyi_builder):
     pyi_builder.test_source("""
         import weasyprint
         """)
+
+
+@importorskip("great_expectations")
+def test_great_expectations(pyi_builder):
+    # Reproduce the error from pyinstaller/pyinstaller-hooks-contrib#445
+    pyi_builder.test_source("""
+        from great_expectations.render.view import view
+        v = view.DefaultJinjaView()
+        """)
+
+
+@importorskip('pyshark')
+def test_pyshark(pyi_builder):
+    pyi_builder.test_source(
+        """
+        import pyshark
+        #capture = pyshark.FileCapture('/tmp/networkpackages.cap')
+        #data = [print x for x in capture]
+        #print(data)
+        """
+    )
+
+
+@importorskip('pyqtgraph')
+@importorskip('PyQt5')
+def test_pyqtgraph(pyi_builder):
+    pyi_builder.test_source(
+        """
+        import pyqtgraph.graphicsItems.PlotItem
+        import pyqtgraph.graphicsItems.ViewBox.ViewBoxMenu
+        import pyqtgraph.imageview.ImageView
+        """
+    )
+
+
+@importorskip('hydra')
+def test_hydra(pyi_builder, tmpdir):
+    config_file = str((Path(__file__) / '../data/test_hydra/config.yaml').resolve(strict=True).as_posix())
+
+    pyi_builder.test_source(
+        """
+        import os
+
+        import hydra
+        from omegaconf import DictConfig, OmegaConf
+
+        config_path = os.path.join(os.path.dirname(__file__), 'conf')
+
+        @hydra.main(config_path=config_path, config_name="config")
+        def my_app(cfg):
+            assert cfg.test_group.secret_string == 'secret'
+            assert cfg.test_group.secret_number == 123
+
+        if __name__ == "__main__":
+            my_app()
+        """,
+        pyi_args=['--add-data', os.pathsep.join((config_file, 'conf'))]
+    )
+
+
+@importorskip('pywintypes')
+def test_pywintypes(pyi_builder):
+    pyi_builder.test_source("""
+        import pywintypes
+        """)
+
+
+@importorskip('pythoncom')
+def test_pythoncom(pyi_builder):
+    pyi_builder.test_source("""
+        import pythoncom
+        """)
